@@ -11,7 +11,10 @@ from . import upsert2
 
 
 # A signal that is emitted when any bulk operation occurs
-post_bulk_operation = Signal(providing_args=['model'])
+post_bulk_operation = Signal()
+"""
+providing_args=['model']
+"""
 
 
 def id_dict(queryset):
